/*  Hint file for the MSWin32 platform, Visual C compiler.
 *
 *  If this configuration doesn't work, look at the file "c-none.h"
 *  for how to set the configuration options.
 */

/* These hints thanks to Gurusamy Sarathy <gsar@engin.umich.edu> */

#undef SP	/* in case this gets pulled in after perl.h */
#include <pdcurses.h>

#ifdef C_PANELSUPPORT
#include <panel.h>
#endif

#define C_LONGNAME
#define C_LONG0ARGS
#undef  C_LONG2ARGS

#define C_TOUCHLINE
#define C_TOUCH3ARGS
#undef  C_TOUCH4ARGS
